==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/items/NodeRevisionsTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NodeRevisionsTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Revision, UnitBox> {
	public _37_4_01120988448 _37_4_01120988448;
	public NodeRevisionsTableOperationsItem._37_4_01120988448. Restore restore;

    public NodeRevisionsTableOperationsItem(UnitBox box) {
        super(box);
        id("a_1811963633");
    }

    @Override
	public void init() {
		super.init();
		if (_37_4_01120988448 == null) _37_4_01120988448 = register(new _37_4_01120988448(box()).<_37_4_01120988448>id("a1284430134").owner(NodeRevisionsTableOperationsItem.this));
		if (_37_4_01120988448 != null) restore = _37_4_01120988448.restore;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_37_4_01120988448 != null) _37_4_01120988448.unregister();
	}

	public class _37_4_01120988448 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NodeRevisionsTableOperationsItem._37_4_01120988448. Restore restore;

		public _37_4_01120988448(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (restore == null) restore = register(new Restore(box()).<Restore>id("a111404379").owner(NodeRevisionsTableOperationsItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (restore != null) restore.unregister();
		}

		public class Restore extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Restore(UnitBox box) {
				super(box);
				_title("Restaurar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Restore");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}

==> unit-2.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/items/NodeRevisionsTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NodeRevisionsTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Revision, UnitBox> {
	public _37_4_01974563943 _37_4_01974563943;
	public NodeRevisionsTableOperationsItem._37_4_01974563943. Restore restore;

	public NodeRevisionsTableOperationsItem(UnitBox box) {
		super(box);
		id("a_1811963633");
	}

	@Override
	public void init() {
		super.init();
		if (_37_4_01974563943 == null) _37_4_01974563943 = register(new _37_4_01974563943(box()).<_37_4_01974563943>id("a_1027646972").owner(NodeRevisionsTableOperationsItem.this));
		if (_37_4_01974563943 != null) restore = _37_4_01974563943.restore;
	}

	@Override
	public void remove() {
		super.remove();
		if (_37_4_01974563943 != null) _37_4_01974563943.unregister();
	}

	public class _37_4_01974563943 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NodeRevisionsTableOperationsItem._37_4_01974563943. Restore restore;

		public _37_4_01974563943(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (restore == null) restore = register(new Restore(box()).<Restore>id("a111404379").owner(NodeRevisionsTableOperationsItem.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (restore != null) restore.unregister();
		}

		public class Restore extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Restore(UnitBox box) {
				super(box);
				_title("Restaurar");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Restore");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}
}
